@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -32,6 +32,9 @@ FAILEDOPERATION_CLOUDSTORAGEAIPACKAGEEXPIRETIMEEXCEEDED = 'FailedOperation.Cloud
 # 产品未开通视频AI分析服务
 FAILEDOPERATION_CLOUDSTORAGEAISERVICENOTENABLED = 'FailedOperation.CloudStorageAIServiceNotEnabled'
 
+# 云存 AI 分析任务已存在，不支持重复创建
+FAILEDOPERATION_CLOUDSTORAGEAISERVICETASKALREADYEXISTS = 'FailedOperation.CloudStorageAIServiceTaskAlreadyExists'
+
 # 需先开通云存套餐
 FAILEDOPERATION_CLOUDSTORAGEPACKAGEREQUIRED = 'FailedOperation.CloudStoragePackageRequired'
 
@@ -278,6 +281,9 @@ INVALIDPARAMETERVALUE_PRODUCTPARMSERROR = 'InvalidParameterValue.ProductParmsErr
 # 项目参数错误。
 INVALIDPARAMETERVALUE_PROJECTPARMSERROR = 'InvalidParameterValue.ProjectParmsError'
 
+# PushEnvironment 非法。
+INVALIDPARAMETERVALUE_PUSHENVIRONMENTINVALID = 'InvalidParameterValue.PushEnvironmentInvalid'
+
 # 转发的topic格式错误。
 INVALIDPARAMETERVALUE_REPUBLISHTOPICFORMATERROR = 'InvalidParameterValue.RepublishTopicFormatError'
 
@@ -290,6 +296,12 @@ INVALIDPARAMETERVALUE_SELECTKEYFROMBINARYPAYLOAD = 'InvalidParameterValue.Select
 # 开始时间晚于结束时间。
 INVALIDPARAMETERVALUE_STARTTIMELATERENDTIME = 'InvalidParameterValue.StartTimeLaterEndTime'
 
+# TPNSAndroidAccessID, TPNSAndroidSecretKey, TPNSAndroidRegion validation failed。
+INVALIDPARAMETERVALUE_TPNSANDROIDVALIDATIONFAILED = 'InvalidParameterValue.TPNSAndroidValidationFailed'
+
+# TPNSiOSAccessID, TPNSiOSSecretKey, TPNSiOSRegion validation failed。
+INVALIDPARAMETERVALUE_TPNSIOSVALIDATIONFAILED = 'InvalidParameterValue.TPNSiOSValidationFailed'
+
 # Topic已存在。
 INVALIDPARAMETERVALUE_TOPICPOLICYALREADYEXIST = 'InvalidParameterValue.TopicPolicyAlreadyExist'
 
@@ -356,9 +368,15 @@ RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 # 已有量产进行，请等待量产完成。
 RESOURCEINSUFFICIENT_BATCHPRODUCTIONISRUNNING = 'ResourceInsufficient.BatchProductionIsRunning'
 
+# 云存 AI 分析任务创建额度不足
+RESOURCEINSUFFICIENT_CLOUDSTORAGEAISERVICETASKQUOTAINSUFFICIENT = 'ResourceInsufficient.CloudStorageAIServiceTaskQuotaInsufficient'
+
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
 
+# App不存在。
+RESOURCENOTFOUND_APPNOTEXISTS = 'ResourceNotFound.AppNotExists'
+
 # 量产不存在。
 RESOURCENOTFOUND_BATCHPRODUCTIONNOTEXIST = 'ResourceNotFound.BatchProductionNotExist'
 
@@ -479,7 +497,7 @@ UNAUTHORIZEDOPERATION_NOPERMISSIONTOSTUDIOPRODUCT = 'UnauthorizedOperation.NoPer
 # 无权操作该房间
 UNAUTHORIZEDOPERATION_NOPERMISSIONTOTRTCROOM = 'UnauthorizedOperation.NoPermissionToTRTCRoom'
 
-# 您的帐号未实名认证，请登录腾讯云进行实名认证
+# 您的账号未实名认证，请登录腾讯云进行实名认证
 UNAUTHORIZEDOPERATION_NOVERIFIED = 'UnauthorizedOperation.NoVerified'
 
 # 没有权限。
