@@ -485,6 +485,7 @@ class LcicClient(AbstractClient):
 
     def DeleteRoom(self, request):
         """删除房间
+        删除课堂前，请先删除该课堂下的各类资源（包括录制文件、板书等），并解绑相关课件。
 
         :param request: Request instance for DeleteRoom.
         :type request: :class:`tencentcloud.lcic.v20220817.models.DeleteRoomRequest`
@@ -1108,6 +1109,8 @@ class LcicClient(AbstractClient):
 
     def DescribeWhiteBoardSnapshot(self, request):
         """查询白板板书截图
+        课程结束后，可以查询和以图片的形式导出这些内容，方便后续查看、整理与分享。
+        注意：不支持屏幕共享中的板书导出。
 
         :param request: Request instance for DescribeWhiteBoardSnapshot.
         :type request: :class:`tencentcloud.lcic.v20220817.models.DescribeWhiteBoardSnapshotRequest`
