@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,9 +14,6 @@
 # limitations under the License.
 
 
-# CAM签名/鉴权错误。
-AUTHFAILURE = 'AuthFailure'
-
 # 交易流程异常
 FAILEDOPERATION_TRANSACTIONEXCEPTION = 'FailedOperation.TransactionException'
 
@@ -50,27 +47,12 @@ INVALIDPARAMETER = 'InvalidParameter'
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
-# 无法获取到可加速的运营商信息
-INVALIDPARAMETERVALUE_VENDORNOTFOUND = 'InvalidParameterValue.VendorNotFound'
-
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
-# 缺少参数错误。
-MISSINGPARAMETER = 'MissingParameter'
-
 # 操作被拒绝。
 OPERATIONDENIED = 'OperationDenied'
 
-# 不建议加速。
-OPERATIONDENIED_ACCELERATIONNOTSUGGEST = 'OperationDenied.AccelerationNotSuggest'
-
-# 中国电信加速token过期。
-OPERATIONDENIED_CTCCTOKENEXPIRED = 'OperationDenied.CTCCTokenExpired'
-
-# 相同加速间隔时间过短。
-OPERATIONDENIED_CREATEQOSEXCEEDLIMIT = 'OperationDenied.CreateQosExceedLimit'
-
 # 该设备未开启永久授权
 OPERATIONDENIED_DEVICENOTFOUND = 'OperationDenied.DeviceNotFound'
 
@@ -104,33 +86,15 @@ OPERATIONDENIED_NOTALLOWEDTOPAY = 'OperationDenied.NotAllowedToPay'
 # 重复购买
 OPERATIONDENIED_REPEATPURCHASE = 'OperationDenied.RepeatPurchase'
 
-# 请求运营商加速超时。
-OPERATIONDENIED_REQUESTQOSTIMEOUT = 'OperationDenied.RequestQosTimeout'
-
 # 截断开关已经被开启
 OPERATIONDENIED_TRUNCFLAGON = 'OperationDenied.TruncFlagOn'
 
 # 未实名认证
 OPERATIONDENIED_UNAUTHORIZEDUSER = 'OperationDenied.UnauthorizedUser'
 
-# 该用户加速已取消，不处于加速状态。
-OPERATIONDENIED_USERNONACCELERATED = 'OperationDenied.UserNonAccelerated'
-
-# 该用户不在运营商网络可加速范围内
-OPERATIONDENIED_USEROUTOFCOVERAGE = 'OperationDenied.UserOutOfCoverage'
-
 # 当前账号尚未注册为厂商。
 OPERATIONDENIED_VENDORNOTREGISTER = 'OperationDenied.VendorNotRegister'
 
-# 运营商返回结果错误。
-OPERATIONDENIED_VENDORRETURNERROR = 'OperationDenied.VendorReturnError'
-
-# 运营商服务器临时错误。
-OPERATIONDENIED_VENDORSERVERERROR = 'OperationDenied.VendorServerError'
-
-# 请求的次数超过了频率限制。
-REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'
-
 # 资源被占用。
 RESOURCEINUSE = 'ResourceInUse'
 
